#
# spec file for package tilda
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tilda
Version:        1.4.1
Release:        lp151.2.2
Summary:        A Gtk based drop down terminal for Linux and Unix
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            https://github.com/lanoxx/tilda/
Source0:        https://github.com/lanoxx/%{name}/archive/%{name}-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  gtk3-devel
BuildRequires:  update-desktop-files
BuildRequires:  vte-devel
BuildRequires:  pkgconfig(libconfuse)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tilda is a terminal emulator and can be compared with other popular terminal
emulators such as gnome-terminal (Gnome), Konsole (KDE), xterm and many others.
The specialities of Tilda are that it does not behave like a normal window
but instead it can be pulled up and down from the top of the screen with
a special hotkey. Additionally Tilda is highly configurable.
It is possible to configure the hotkeys for keybindings,
change the appearance and many options that affect the behavior of Tilda.
The screen shots below show some of the options that Tilda provides.

%lang_package
%prep
%setup -q -n %{name}-%{name}-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%if 0%{?suse_version} >= 1315
%configure
%else
%configure --disable-vte-2.91
%endif
make %{?_smp_mflags}

%install
%makeinstall
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README.md ChangeLog HACKING.md TODO.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Feb 21 2018 malcolmlewis@opensuse.org
- Updated to version 1.4.1:
  * Traslation updates.
- Changes from version 1.4.0:
  * Fixes a problem with close-tab action in the context menu.
  * The default word matching expression now matches IPv6
    addresses.
  * The keybindings in the wizard are now displayed in form of a
    list.
  * Fixed an issue which broke the transparency feature after
    changing the color scheme.
  * Fixed an issue that prevented the initial tab title from being
    correctly set.
  * Tilda now supports a new command line option to specify the
    configuration file.
  * The 'Tab Position' option has been moved to appearance section
    in the wizard.
  * New option 'Expand Tabs' causes tabs in the tilda window to
    fill all available horizontal space.
  * New option 'Show Single Tab' to show the tab bar also when
    only a single tab is open.
  * Tilda can now be configured to show a confirmation dialog when
    closing a tab or when when tilda is closed.
  * Tilda now knows a new color scheme called 'Snazzy'.
  * The tab title learned more options to configure behavior of
    long tab tiles.
  * The option for double buffering has long been deprecated and
    was removed in this release.
- Changes from version 1.3.4:
  * Fixed crash that occured when the VTE version in use is 0.3.
- There is an issue when trying to run on wayland, a work-around
  is to start tilda via 'env GDK_BACKEND=x11 /usr/bin/tilda', but
  hotkey support may be lost (boo#1080341).
* Sun Sep 25 2016 malcolmlewis@opensuse.org
- Update to version 1.3.3:
  + Bumped GTK+ version to 3.10, we are already implicitly
    depending on it.
  + Fixed the close-tab regression introduced in the last patch.
  + Fixed CTRL+SHIFT+W closing two tabs.
- Changes from version 1.3.2:
  + Updated Hacking.md's instructions to reflect VTE 2.91 api bump.
  + Added a widget name to the search widget for easier styling.
  + Several code cleanups and a few deprecation warnings where
    removed.
  + Added default styling to the tilda search bar.
  + Cleanup code for CSS loading. It now reports an error if
    something went wrong.
  + Fixed a problem that caused tilda to close two tabs when the
    close tab hotkey was used.
  + The preference dialog is now also shown above the tilda window
    if the tilda window is in fullscreen mode.
- Changes from version 1.3.1:
  + Transparency regression for GNOME shell fixed.
  + Images in the appdata file and Readme.md have been updated.
  + Fixed an issue that would the background transparancy to be
    reset on a color palette change.
- NOTE: No wayland support (yet?).
* Sat Nov 21 2015 rpm@fthiessen.de
- Updated to version 1.3.0:
  * Clean up SPEC
  * Removed now obsolete patches (fixed in this version):
  * tilda-add-xrandr-check.patch
  * tilda-desktop-icon.patch
  * tilda-fix-gdk-x11-window-set-user-time.patch
  * tilda-fix-glib-include.patch
  * tilda-fix-pointers.patch
* Thu Feb 23 2012 malcolmlewis@opensuse.org
- Add tilda-add-xrandr-check.patch: Add check for the presence of
  the xrandr headers in configure since xrandr is used in the code
  (sf#3492123).
* Tue Feb 21 2012 dimstar@opensuse.org
- Update BuildRequires after reorganization of xorg-x11 packages:
  + On 12.2/Factory and later, add libX11-devel, libXrandr-devel
    and libXt-devel.
  + Only use xorg-x11-libXt-devel on 12.1 and earlier.
* Thu Jan 12 2012 malcolmlewis@opensuse.org
- Major spec file cleanup via spec-cleaner.
- Add tilda-fix-glib-include.patch: Only <glib.h> can be included
  directly (sf#3473000).
- Add tilda-desktop-icon.patch: Fix fullpath to icon and icon file
  extension (sf#3473002).
- Upstream tilda-0.9.6-pointers.patch: Fix 64bit-portability-issue
  (sf#3473004).
- Rename tilda-0.9.6-fix-bnc633863.patch: To
  tilda-fix-gdk-x11-window-set-user-time.patch
  (bnc#633863, sf#2988694).
- Update spec file License field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
* Mon Aug 23 2010 andrea@opensuse.org
- added tilda-0.9.6-fix-bnc633863.patch to fix a segfault
  (thanks to mandriva https://qa.mandriva.com/show_bug.cgi?id=58153)
- renamed desktop_icon.patch according to packaging standards
- fixed RPM group
* Mon Feb 23 2009 mhrusecky@suse.cz
- explicit cast (tilda-0.9.6-pointers) to fix rpmlint error
- bziped sources to get rid off the last rpmlint warning
* Fri Oct 31 2008 claes.backstrom@fsfe.org
- Small fixes to build for factory
- Add GenericName to .desktop
- Remove absolute patch to icon in .desktop
- Create lang package
- Removed debug package
* Wed Aug 13 2008 claes.backstrom@fsfe.org
- Initial Package
